==> net.bluemind.backend.mail.api.php-4.9.3879.jar: BM/MailboxFoldersClient.php <==
<?php

/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2017
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
namespace BM;
require_once 'GlobalEnv.php';

/**
 * Implementation of net.bluemind.backend.mail.api.IMailboxFolders.
 */

class MailboxFoldersClient {

  protected $base;
  protected $sid;
  protected $partition;
  protected $mailboxRoot;

  /*
   * Constructor.
   *
   * @param base
   * @param sid
   * @param partition
   * @param mailboxRoot
   *
   */
  public function __construct($base, $sid , $partition, $mailboxRoot) {
    $this->sid = $sid;
    $this->base = $base."/api/mail_folders/{partition}/{mailboxRoot}";
    $this->partition = $partition;
    $this->base = str_replace("{partition}", urlencode($partition), $this->base);
    $this->mailboxRoot = $mailboxRoot;
    $this->base = str_replace("{mailboxRoot}", urlencode($mailboxRoot), $this->base);
  }


  /*
   * @return
   */
  public function getVersion() {
    $postUri = "/_version";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param since
   * @param arg1
   * @return
   */
  public function filteredChangesetById( $since ,  $arg1  ) {
    $postUri = "/_filteredChangesetById";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "since" => $since);

    $body = null;
    $body = $arg1;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param uid
   * @param arg1
   * @return
   */
  public function itemChangelog( $uid ,  $arg1  ) {
    $postUri = "/{uid}/_itemchangelog";
    $method = "GET";

    $postUri = str_replace("{uid}", urlencode($uid), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $arg1;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param since
   * @return
   */
  public function changeset( $since  ) {
    $postUri = "/_changeset";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array(
      "since" => $since);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param since
   * @return
   */
  public function changesetById( $since  ) {
    $postUri = "/_changesetById";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array(
      "since" => $since);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param arg0
   * @return
   */
  public function containerChangelog( $arg0  ) {
    $postUri = "/_changelog";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $arg0;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param filter
   * @param knownContainerVersion
   * @param limit
   * @param offset
   * @return
   */
  public function allIds( $filter ,  $knownContainerVersion ,  $limit ,  $offset  ) {
    $postUri = "/_itemIds";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array(
      "filter" => $filter,      "knownContainerVersion" => $knownContainerVersion,      "limit" => $limit,      "offset" => $offset);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function all() {
    $postUri = "/_all";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param name
   * @return
   */
  public function byName( $name  ) {
    $postUri = "/byName/{name}";
    $method = "GET";

    $postUri = str_replace("{name}", urlencode($name), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param uid
   * @return
   */
  public function getComplete( $uid  ) {
    $postUri = "/{uid}/complete";
    $method = "GET";

    $postUri = str_replace("{uid}", urlencode($uid), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function root() {
    $postUri = "/_root";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param query
   * @return
   */
  public function searchItems( $query  ) {
    $postUri = "/_search";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $query;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param arg0
   * @return
   */
  public function multipleGetById( $arg0  ) {
    $postUri = "/_mgetById";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $arg0;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function getCompleteById( $id  ) {
    $postUri = "/{id}/completeById";
    $method = "GET";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param folderDestinationId
   * @param mailboxItems
   * @return
   */
  public function importItems( $folderDestinationId ,  $mailboxItems  ) {
    $postUri = "/importItems/{folderDestinationId}";
    $method = "PUT";

    $postUri = str_replace("{folderDestinationId}", urlencode($folderDestinationId), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $mailboxItems;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function emptyFolder( $id  ) {
    $postUri = "/empty/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function removeMessages( $id  ) {
    $postUri = "/removeMessages/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function markFolderAsRead( $id  ) {
    $postUri = "/markAsRead/{id}";
    $method = "PUT";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param value
   * @return
   */
  public function createBasic( $value  ) {
    $postUri = "";
    $method = "PUT";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $value;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param hierarchyId
   * @param value
   * @return
   */
  public function createForHierarchy( $hierarchyId ,  $value  ) {
    $postUri = "/id/{hierarchyId}";
    $method = "PUT";

    $postUri = str_replace("{hierarchyId}", urlencode($hierarchyId), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $value;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @param value
   * @return
   */
  public function updateById( $id ,  $value  ) {
    $postUri = "/id/{id}";
    $method = "POST";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $value;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function deleteById( $id  ) {
    $postUri = "/id/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function deepDelete( $id  ) {
    $postUri = "/deep/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }


  /*
   * Execute the request
   *
   * @param url
   * @param data
   * @param body
   */
  private function execute($url, $queryParam, $body, $method) {

    $curl = curl_init();

    $headers = array();
    array_push($headers, 'X-BM-ApiKey: '.$this->sid);

    if (sizeof($queryParam) > 0) {
      $url .= '?'.http_build_query($queryParam);
    }

    curl_setopt_array($curl, GlobalEnv::$curlOptions + array(
      CURLOPT_URL => $url,
      CURLOPT_HTTPHEADER => $headers,
      CURLOPT_CUSTOMREQUEST => $method)
    );

    if ($method == 'POST') {
      curl_setopt($curl, CURLOPT_POST, TRUE);
      curl_setopt($curl, CURLOPT_POSTFIELDS, array());
    }

    if (is_resource($body)) {
      if ($method == 'PUT') {
        curl_setopt($curl, CURLOPT_PUT, TRUE);
      }
      $size = fstat($body)['size'];
      curl_setopt($curl, CURLOPT_INFILE, $body);
      curl_setopt($curl, CURLOPT_INFILESIZE, $size);
    } else {
      if (is_object($body) && method_exists($body, 'serialize')) {
        $body = $body->serialize();
      } else if (is_object($body)) {
        $body = json_encode($body);
      } else if (is_array($body)) {
        $body = json_encode($body);
      } else if (is_string($body)) {
        $body = json_encode($body);
      }
      $size = strlen($body);
      array_push($headers, 'Content-Type: application/json');
      array_push($headers, 'Content-Length: '.$size);
      curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
      curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
    }

    $resp = curl_exec($curl);
    if ($resp === false) {
      throw new \Exception(curl_error($curl));
    } 
    curl_close($curl);
    if (!$resp) {
      return;
    }
    $js = json_decode($resp);
    if ($js === NULL) {
      return $resp;
    }
    if (isset($js->errorCode)) {
      throw new \Exception($js->errorCode . ': ' . (isset($js->message) ? ' : ' . $js->message : ''));
    }
    return $js;
  }

}

==> net.bluemind.backend.mail.api.php-5.5.3184.jar: BM/MailboxFoldersClient.php <==
<?php

/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2017
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
namespace BM;
require_once 'GlobalEnv.php';

/**
 * Implementation of net.bluemind.backend.mail.api.IMailboxFolders.
 */

class MailboxFoldersClient {

  protected $base;
  protected $sid;
  protected $partition;
  protected $mailboxRoot;

  /*
   * Constructor.
   *
   * @param base
   * @param sid
   * @param partition
   * @param mailboxRoot
   *
   */
  public function __construct($base, $sid , $partition, $mailboxRoot) {
    $this->sid = $sid;
    $this->base = $base."/api/mail_folders/{partition}/{mailboxRoot}";
    $this->partition = $partition;
    $this->base = str_replace("{partition}", urlencode($partition), $this->base);
    $this->mailboxRoot = $mailboxRoot;
    $this->base = str_replace("{mailboxRoot}", urlencode($mailboxRoot), $this->base);
  }


  /*
   * @return
   */
  public function all() {
    $postUri = "/_all";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param name
   * @return
   */
  public function byName( $name  ) {
    $postUri = "/byName/{name}";
    $method = "GET";

    $postUri = str_replace("{name}", urlencode($name), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param since
   * @return
   */
  public function changeset( $since  ) {
    $postUri = "/_changeset";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array(
      "since" => $since);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param since
   * @return
   */
  public function changesetById( $since  ) {
    $postUri = "/_changesetById";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array(
      "since" => $since);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param folderUid
   * @return
   */
  public function childrensOf( $folderUid  ) {
    $postUri = "/childensof/{folderUid}";
    $method = "GET";

    $postUri = str_replace("{folderUid}", urlencode($folderUid), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param folderItemIds
   * @return
   */
  public function counters( $folderItemIds  ) {
    $postUri = "/_counters";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $folderItemIds;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param value
   * @return
   */
  public function createBasic( $value  ) {
    $postUri = "";
    $method = "PUT";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $value;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param hierarchyId
   * @param value
   * @return
   */
  public function createForHierarchy( $hierarchyId ,  $value  ) {
    $postUri = "/id/{hierarchyId}";
    $method = "PUT";

    $postUri = str_replace("{hierarchyId}", urlencode($hierarchyId), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $value;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function deepDelete( $id  ) {
    $postUri = "/deep/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function deleteById( $id  ) {
    $postUri = "/id/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function emptyFolder( $id  ) {
    $postUri = "/empty/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param since
   * @param arg1
   * @return
   */
  public function filteredChangesetById( $since ,  $arg1  ) {
    $postUri = "/_filteredChangesetById";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "since" => $since);

    $body = null;
    $body = $arg1;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param uid
   * @return
   */
  public function getComplete( $uid  ) {
    $postUri = "/{uid}/complete";
    $method = "GET";

    $postUri = str_replace("{uid}", urlencode($uid), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function getCompleteById( $id  ) {
    $postUri = "/{id}/completeById";
    $method = "GET";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param uid
   * @return
   */
  public function getFullName( $uid  ) {
    $postUri = "/{uid}/fullname";
    $method = "GET";

    $postUri = str_replace("{uid}", urlencode($uid), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function getVersion() {
    $postUri = "/_version";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param folderDestinationId
   * @param mailboxItems
   * @return
   */
  public function importItems( $folderDestinationId ,  $mailboxItems  ) {
    $postUri = "/importItems/{folderDestinationId}";
    $method = "PUT";

    $postUri = str_replace("{folderDestinationId}", urlencode($folderDestinationId), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $mailboxItems;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param uid
   * @param arg1
   * @return
   */
  public function itemChangelog( $uid ,  $arg1  ) {
    $postUri = "/{uid}/_itemchangelog";
    $method = "GET";

    $postUri = str_replace("{uid}", urlencode($uid), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $arg1;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function markFolderAsRead( $id  ) {
    $postUri = "/markAsRead/{id}";
    $method = "PUT";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param arg0
   * @return
   */
  public function multipleGetById( $arg0  ) {
    $postUri = "/_mgetById";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $arg0;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @return
   */
  public function removeMessages( $id  ) {
    $postUri = "/removeMessages/{id}";
    $method = "DELETE";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function root() {
    $postUri = "/_root";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param query
   * @return
   */
  public function searchItems( $query  ) {
    $postUri = "/_search";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $query;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function trash() {
    $postUri = "/_trash";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param id
   * @param value
   * @return
   */
  public function updateById( $id ,  $value  ) {
    $postUri = "/id/{id}";
    $method = "POST";

    $postUri = str_replace("{id}", urlencode($id), $postUri);

    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $value;
    return $this->execute($url, $queryParam, $body, $method);
  }


  /*
   * Execute the request
   *
   * @param url
   * @param data
   * @param body
   */
  private function execute($url, $queryParam, $body, $method) {

    $curl = curl_init();

    $headers = array();
    array_push($headers, 'X-BM-ApiKey: '.$this->sid);

    if (sizeof($queryParam) > 0) {
      $url .= '?'.http_build_query($queryParam);
    }

    curl_setopt_array($curl, GlobalEnv::$curlOptions + array(
      CURLOPT_URL => $url,
      CURLOPT_HTTPHEADER => $headers,
      CURLOPT_CUSTOMREQUEST => $method)
    );

    if ($method == 'POST') {
      curl_setopt($curl, CURLOPT_POST, TRUE);
      curl_setopt($curl, CURLOPT_POSTFIELDS, array());
    }

    if (is_resource($body)) {
      if ($method == 'PUT') {
        curl_setopt($curl, CURLOPT_PUT, TRUE);
      }
      $size = fstat($body)['size'];
      curl_setopt($curl, CURLOPT_INFILE, $body);
      curl_setopt($curl, CURLOPT_INFILESIZE, $size);
    } else {
      if (is_object($body) && method_exists($body, 'serialize')) {
        $body = $body->serialize();
      } else if (is_object($body)) {
        $body = json_encode($body);
      } else if (is_array($body)) {
        $body = json_encode($body);
      } else if (is_string($body)) {
        $body = json_encode($body);
      }
      $size = strlen($body);
      array_push($headers, 'Content-Type: application/json');
      array_push($headers, 'Content-Length: '.$size);
      curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
      curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
    }

    $resp = curl_exec($curl);
    if ($resp === false) {
      throw new \Exception(curl_error($curl));
    } 
    curl_close($curl);
    if (!$resp) {
      return;
    }
    $js = json_decode($resp);
    if ($js === NULL) {
      return $resp;
    }
    if (isset($js->errorCode)) {
      throw new \Exception($js->errorCode . ': ' . (isset($js->message) ? ' : ' . $js->message : ''));
    }
    return $js;
  }

}
